@@ -37,14 +37,8 @@
 #' pedestrian %>% 
 #'   filter_index("2015-03-23 10" ~ "2015-10-31 12")
 filter_index <- function(.data, ...) {
-  UseMethod("filter_index")
-}
-
-#' @export
-filter_index.tbl_ts <- function(.data, ...) {
-  index <- eval_tidy(index(.data), data = .data)
-  lgl <- time_in(index, ...)
-  filter(.data, lgl)
+  idx <- index(.data)
+  filter(.data, time_in(!! idx, ...))
 }
 
 #' If time falls in the ranges using compact expressions
@@ -129,7 +123,6 @@ time_in.yearqtr <- time_in.POSIXct
 time_in.numeric <- time_in.POSIXct
 
 #' @importFrom stats start end
-#' @importFrom lubridate tz<-
 start.numeric <- function(x, y = NULL, ...) {
   if (is_null(y)) {
     min(x)
@@ -175,7 +168,7 @@ start.Date <- function(x, y = NULL, ...) {
     abort_not_chr(y, class = "Date")
     anytime::assertDate(y)
     y <- anytime::utcdate(y, tz = "UTC")
-    tz(y) <- lubridate::tz(x)
+    attr(y, "tzone") <- NULL
     y
   }
 }
@@ -190,7 +183,7 @@ end.Date <- function(x, y = NULL, ...) {
     lgl_yrmth <- nchar(y) < 8 & nchar(y) > 4
     lgl_yr <- nchar(y) < 5
     y <- anytime::utcdate(y, tz = "UTC")
-    tz(y) <- lubridate::tz(x)
+    attr(y, "tzone") <- NULL
     if (any(lgl_yrmth)) {
       y[lgl_yrmth] <- lubridate::rollback(
         y[lgl_yrmth] + lubridate::period(1, "month"), 
@@ -213,8 +206,7 @@ start.POSIXct <- function(x, y = NULL, ...) {
     abort_not_chr(y, class = "POSIXct")
     anytime::assertTime(y)
     y <- anytime::utctime(y, tz = "UTC")
-    tz(y) <- lubridate::tz(x)
-    y
+    lubridate::force_tz(y, lubridate::tz(x), roll = TRUE)
   }
 }
 
@@ -226,10 +218,10 @@ end.POSIXct <- function(x, y = NULL, ...) {
     anytime::assertTime(y)
     
     lgl_date <- nchar(y) > 7 & nchar(y) < 11
-    lgl_yrmth <- nchar(y) < 8 & nchar(y) > 4
+    lgl_yrmth <- nchar(y) < 9 & nchar(y) > 4
     lgl_yr <- nchar(y) < 5
     y <- anytime::utctime(y, tz = "UTC")
-    tz(y) <- lubridate::tz(x)
+    y <- lubridate::force_tz(y, lubridate::tz(x), roll = TRUE)
     if (any(lgl_date)) {
       y[lgl_date] <- y[lgl_date] + lubridate::period(1, "day")
     }
